import OEmpty from '@/components/o-empty'
import request from '@/helpers/request'
import { Button, Dialog, Field, Image, List, Popup, showToast } from 'vant'
import { defineComponent, onMounted, reactive } from 'vue'
import { useRoute, useRouter } from 'vue-router'
import styles from './photo.module.less'
import iconPhoneDefaut from '../images/icon-photo-default.png'

export default defineComponent({
  name: 'phone',
  setup() {
    const route = useRoute()
    const router = useRouter()
    const state = reactive({
      status: false,
      isLoading: false,
      photoName: null, // 相册名称
      list: [] as any,
      listState: {
        dataShow: true, // 判断是否有数据
        loading: false,
        finished: false
      },

      params: {
        page: 1,
        rows: 20
      }
    })

    const onAddPhoto = async () => {
      try {
        if (!state.photoName) {
          showToast('请输入相册名称')
          state.status = true
          return
        }
        await request.post('/api-school/orchestraPhotoAlbum/save', {
          data: {
            orchestraId: route.query.id,
            name: state.photoName
          }
        })
        setTimeout(() => {
          showToast('添加成功')
          state.status = false
          state.photoName = null
        }, 100)
        setTimeout(() => {
          state.params.page = 1
          state.list = []
          state.listState.dataShow = true // 判断是否有数据
          state.listState.loading = false
          state.listState.finished = false
          getList()
        }, 1100)
      } catch {
        //
      }
    }

    // 班级列表
    const getList = async () => {
      try {
        if (state.isLoading) return
        state.isLoading = true
        const res = await request.post('/api-school/orchestraPhotoAlbum/page', {
          data: {
            ...state.params,
            orchestraId: route.query.id
          }
        })
        state.listState.loading = false
        const result = res.data || {}
        // 处理重复请求数据
        if (state.list.length > 0 && result.current === 1) {
          return
        }
        const rows = result.rows || []
        state.list = state.list.concat(rows)
        state.listState.finished = result.current >= result.pages
        state.params.page = result.current + 1
        state.listState.dataShow = state.list.length > 0
        state.isLoading = false
      } catch {
        state.listState.dataShow = false
        state.listState.finished = true
        state.isLoading = false
      }
    }

    const onDetail = (item: any) => {
      sessionStorage.setItem('orchestra-detail-tab', 'photo')
      router.push({
        path: '/photo-detail',
        query: {
          photoId: item.id,
          name: item.name
        }
      })
    }

    onMounted(() => {
      getList()
    })
    return () => (
      <div class={styles.phone}>
        <Button icon="plus" block class={styles.addPhone} onClick={() => (state.status = true)}>
          新建相册
        </Button>

        {state.listState.dataShow ? (
          <List
            v-model:loading={state.listState.loading}
            finished={state.listState.finished}
            finishedText=" "
            onLoad={getList}
            immediateCheck={false}
          >
            <div class={styles.phoneContainer}>
              {state.list.map((item: any) => (
                <div class={styles.item} onClick={() => onDetail(item)}>
                  {item.coverUrl ? (
                    <Image class={styles.img} src={item.coverUrl} />
                  ) : (
                    <div class={[styles.img, styles.default]}>
                      <Image src={iconPhoneDefaut} class={styles.defaultImg} />
                    </div>
                  )}

                  <p class={[styles.name, 'van-ellipsis']}>{item.name}</p>
                  <p class={styles.num}>{item.photoCount}张</p>
                </div>
              ))}
            </div>
          </List>
        ) : (
          <OEmpty btnStatus={false} classImgSize="SMALL" tips="暂无相册" />
        )}

        <Popup v-model:show={state.status} round style={{ width: '80%' }}>
          <div class={styles.container}>
            <div class={styles.dialogTitle}>
              <i></i>
              新建相册
            </div>
            <Field
              class={styles.phoneName}
              v-model={state.photoName}
              placeholder="请输入相册名称"
              maxlength={15}
            />

            <div class={['van-hairline--top van-dialog__footer']}>
              <Button
                onClick={() => (state.status = false)}
                class={['van-button van-button--default van-button--large van-dialog__cancel']}
              >
                取消
              </Button>
              <Button
                onClick={onAddPhoto}
                class={[
                  'van-button van-button--default van-button--large van-dialog__confirm van-hairline--left'
                ]}
              >
                确认
              </Button>
            </div>
          </div>
        </Popup>
      </div>
    )
  }
})
