import OHeader from '@/components/o-header'
import { defineComponent, onMounted, reactive } from 'vue'
import styles from './order-detail.module.less'
import Addres from './component/addres'
import OSticky from '@/components/o-sticky'
import { Button, Cell, CellGroup, Image, Popup, Tag } from 'vant'
import Payment from '@/views/adapay/payment'
import { useRoute, useRouter } from 'vue-router'
import OQrcode from '@/components/o-qrcode'
import request from '../request-music'
import item from '@/student/coupons/item'
import { browser, moneyFormat } from '@/helpers/utils'
import { state as baseState } from '@/state'

export default defineComponent({
  name: 'order-detail',
  setup() {
    const route = useRoute()
    const router = useRouter()
    const state = reactive({
      paymentStatus: false,
      showQrcode: false,
      qrCodeUrl: '',
      orderNo: route.query.orderNo,
      orderInfo: {} as any, // 订单信息
      goodsInfos: [] as any, // 订单信息列表
      config: route.query.config ? JSON.parse(route.query.config as any) : {}
    })

    const getOrderDetails = async () => {
      try {
        const { data } = await request.get('/api-student/userPaymentOrder/detail/' + state.orderNo)
        console.log(data)
        const goodsInfos = data.goodsInfos || []
        state.orderInfo = data
        goodsInfos.forEach((item: any) => {
          const img = item.goodsUrl ? item.goodsUrl.split(',')[0] : ''
          item.goodsUrl = img
        })
        state.goodsInfos = goodsInfos
      } catch {
        //
      }
    }

    const onConfirm = (val: any) => {
      const config: any = state.config
      if (val.payCode === 'payResult') {
        router.push({
          path: '/payResult',
          query: {
            pay_channel: val.pay_channel,
            wxAppId: config.wxAppId,
            body: config.body,
            price: config.price
          }
        })
      } else {
        console.log(baseState.user)
        state.qrCodeUrl =
          window.location.origin +
          '/orchestra-student/#/payDefine?pay_channel=' +
          val.pay_channel +
          '&wxAppId=' +
          config.wxAppId +
          '&body=' +
          config.body +
          '&price=' +
          config.price +
          '&orderNo=' +
          config.merOrderNo +
          '&userId=' +
          config.userId
        console.log(state.qrCodeUrl, 'qrCodeUrl')
        state.showQrcode = true
        state.paymentStatus = false
      }
    }

    const beforeSubmit = () => {
      const pt = state.config.paymentChannel
      let payCode = 'qrCode'
      // 判断当前浏览器
      if (browser().weixin) {
        // 微信浏览器
        if (pt == 'alipay_qr' || pt == 'alipay_wap') {
          payCode = 'qrCode'
        } else if (pt == 'wx_pub') {
          payCode = 'pay'
        }
      } else if (browser().alipay) {
        // 支付宝浏览器
        if (pt == 'alipay_wap') {
          // 支付宝 H5 支付
          payCode = 'pay'
        } else {
          payCode = 'qrCode'
        }
      } else {
        payCode = 'qrCode'
      }

      onConfirm({
        payCode: payCode == 'qrCode' ? 'payDefine' : 'payResult',
        pay_channel: pt
      })
    }

    const onSubmit = () => {
      const pt = state.config.paymentChannel
      // 判断是否有支付方式
      if (pt) {
        beforeSubmit()
      } else {
        state.paymentStatus = true
      }
    }

    onMounted(() => {
      getOrderDetails()
    })
    return () => (
      <>
        <OHeader />
        <div class={styles.cartConfirm}>
          <div class={styles.cartConfirmBox}>
            <Addres />
          </div>

          <CellGroup style={{ margin: 0 }}>
            {state.goodsInfos &&
              state.goodsInfos.map((goods: any) => (
                <Cell class={styles.cellItem} center>
                  {{
                    icon: () => <Image class={styles.img} src={goods.goodsUrl} />,
                    title: () => (
                      <div class={styles.goodsContent}>
                        <h2>{goods.goodsName}</h2>
                        <Tag type="primary">{goods.brandName}</Tag>
                        <p class={styles.goodsNum}>x 1</p>
                      </div>
                    ),
                    value: () => (
                      <span class={styles.cellPrice}>
                        {goods.currentPrice > 0 ? moneyFormat(goods.currentPrice) : '赠送'}
                      </span>
                    )
                  }}
                </Cell>
              ))}
          </CellGroup>
        </div>

        <OSticky position="bottom" background="white">
          <div class={styles.paymentContainer}>
            <div class={styles.payemntPrice}>
              <p class={styles.needPrice}>
                共需支付：<span>¥{moneyFormat(state.orderInfo.currentPrice)}</span>
              </p>
            </div>
            <div class={styles.paymentBtn}>
              <Button
                color="linear-gradient(135deg, #FF8C4A 0%, #FF531C 100%)"
                round
                onClick={onSubmit}
              >
                立即购买
              </Button>
            </div>
          </div>
        </OSticky>

        <Popup
          show={state.paymentStatus}
          closeOnClickOverlay={false}
          position="bottom"
          round
          closeOnPopstate
          safeAreaInsetBottom
          style={{ minHeight: '30%' }}
        >
          <Payment
            paymentConfig={state.orderInfo}
            onClose={() => (state.paymentStatus = false)}
            onBackOut={() => {
              console.log('back')
            }}
            onConfirm={(val: any) => onConfirm(val)}
          />
        </Popup>

        <Popup
          v-model:show={state.showQrcode}
          // position="bottom"
          style={{ background: 'transparent', overflow: 'initial' }}
          safeAreaInsetBottom={true}
        >
          <div class={styles.codeContainer}>
            <i class={styles.codeClose} onClick={() => (state.showQrcode = false)}></i>
            <div class={styles.codeImg}>
              <div class={styles.codeContent}>
                <h2 class={styles.codeTitle}>乐团报名</h2>
                <div class={styles.codeName}>请截图下方二维码 登录支付宝扫码支付</div>

                <div class={styles.codeQr}>
                  <OQrcode text={state.qrCodeUrl} size={'400'} />
                </div>
                <div style={{ textAlign: 'center' }}>
                  <span class={styles.codeBtnText}>请在30分钟内扫码支付</span>
                </div>
                <div class={styles.codeTips}>
                  <div class={styles.tipsTitle}>使用说明：</div>
                  <div class={styles.tipsContent}>
                    1.长按二维码保存图片到相册（或截屏保存到相册）
                    <br />
                    2.打开支付宝扫一扫
                    <br />
                    3.选择相册中的二维码
                    <br />
                    4.请在30分钟内扫码支付
                  </div>
                </div>
              </div>
            </div>
          </div>
        </Popup>
      </>
    )
  }
})
